#[repr(u8)]pub enum AccessControlEntryPrivilege {
View = 1,
Proxyview = 2,
Operate = 3,
Manage = 4,
Administer = 5,
}Variants
View = 1
Can read and observe all (except Access Control Cluster)
Proxyview = 2
Operate = 3
View privileges, and can perform the primary function of this Node (except Access Control Cluster)
Manage = 4
Operate privileges, and can modify persistent configuration of this Node (except Access Control Cluster)
Administer = 5
Manage privileges, and can observe and modify the Access Control Cluster
Implementations