#[repr(u8)]pub enum AccessRestrictionType {
Attributeaccessforbidden = 0,
Attributewriteforbidden = 1,
Commandforbidden = 2,
Eventforbidden = 3,
}Variants
Attributeaccessforbidden = 0
Clients on this fabric are currently forbidden from reading and writing an attribute
Attributewriteforbidden = 1
Clients on this fabric are currently forbidden from writing an attribute
Commandforbidden = 2
Clients on this fabric are currently forbidden from invoking a command
Eventforbidden = 3
Clients on this fabric are currently forbidden from reading an event
Implementations